import type { Ref, SyntheticEvent } from 'react';
import type { BaseProps, ForwardRefForwardPropsComponent, PropsWithDefaults, NoChildrenProp, TestIdProp } from '../../types';
export interface AvatarProps extends BaseProps, NoChildrenProp, TestIdProp {
    /** The name of the identity the Avatar represents. */
    name: string;
    /** Content of the Avatar as an image source url. */
    imageSrc?: string;
    /** An icon to render as the content of the avatar. imageSrc will take precedence if passed. */
    icon?: string;
    /** Optional color for the icon to be rendered */
    color?: string;
    /** Optional background color for the avatar. Will be auto computed if not passed */
    backgroundColor?: string;
    /**
     * Shape of the Avatar.
     * @default 'circle'
     */
    shape?: 'circle' | 'squircle';
    /**
     * Avatar size.
     * @default 'm'
     */
    size?: 's' | 'm' | 'l' | 'xl';
    /** If defined, will render status icon on the avatar. */
    status?: 'active';
    /** Optional error handler in the event an image fails to load. */
    onImageError?: (err: SyntheticEvent<HTMLImageElement>) => void;
    /** Ref for the wrapping element. */
    ref?: Ref<HTMLDivElement | HTMLImageElement>;
}
type AvatarPropsWithDefaults = PropsWithDefaults<AvatarProps, 'shape' | 'size'>;
export declare const StyledAvatarImage: import("styled-components").StyledComponent<ForwardRefForwardPropsComponent<import("../Image").ImageProps>, import("styled-components").DefaultTheme, {}, never>;
export declare const StyledAvatar: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, Pick<AvatarPropsWithDefaults, "color" | "size" | "icon" | "backgroundColor" | "ref" | "className" | "shape" | "status" | "testId" | "imageSrc" | "onImageError"> & {
    hasSrc?: boolean;
    hasBrokenImage?: boolean;
}, never>;
export declare const StyledStatus: import("styled-components").StyledComponent<import("react").ForwardRefExoticComponent<Omit<import("../Badges").AlertProps, "ref"> & import("react").RefAttributes<HTMLDivElement>> & {
    getTestIds: (testIdProp?: TestIdProp["testId"]) => import("../../types").TestIdsRecord<readonly []>;
}, import("styled-components").DefaultTheme, Pick<AvatarPropsWithDefaults, "size">, never>;
declare const _default: ForwardRefForwardPropsComponent<AvatarProps> & {
    getTestIds: (testIdProp?: TestIdProp["testId"]) => import("../../types").TestIdsRecord<readonly []>;
};
export default _default;
//# sourceMappingURL=Avatar.d.ts.map