import type { ChangeEvent } from 'react';
import type { NoChildrenProp, TestIdProp, WithAttributes } from '../../types';
import type { FormFieldProps } from '../FormField';
import type { FormControlProps } from '../FormControl';
export type ColorPickerProps = WithAttributes<'input', TestIdProp & NoChildrenProp & {
    /** label for the color picker control */
    label: FormControlProps['label'];
    /**
     * Color picker value in hex
     * @default '#000000'
     */
    value?: FormControlProps['value'];
    /**
     * Show color swatch without hex value display.
     * @default false
     */
    swatchOnly?: boolean;
    /** Visually hides the label region. */
    labelHidden?: FormControlProps['labelHidden'];
    /** It is recommended to pass a simple string to offer guidance. Text will be styled based on status prop. */
    info?: FormControlProps['info'];
    /** Set visual state based on a validation state. */
    status?: FormControlProps['status'];
    /** Layout field elements inline in a row. */
    inline?: FormFieldProps['inline'];
    /** Button when clicked will show additional information on the color picker */
    additionalInfo?: FormFieldProps['additionalInfo'];
    /** onChange event handler that gets called on change of value. */
    onChange?: ColorChangeHandler;
    /** onBeforeClose of the color picker */
    onBeforeClose?: () => void;
}>;
type RGBColor = {
    r: number;
    g: number;
    b: number;
};
type HSLColor = {
    h: number;
    s: number;
    l: number;
};
type ColorResult = {
    hex: string;
    rgb: RGBColor;
    hsl: HSLColor;
};
type ColorChangeHandler = (color: ColorResult, event: ChangeEvent<HTMLInputElement>) => void;
declare const _default: import("react").ForwardRefExoticComponent<Omit<ColorPickerProps, "ref"> & import("react").RefAttributes<HTMLInputElement>> & {
    getTestIds: (testIdProp?: TestIdProp["testId"]) => import("../../types").TestIdsRecord<readonly ["control", "label", "info", "additional-info", "suggestion-accept", "suggestion-reject"]>;
};
export default _default;
//# sourceMappingURL=ColorPicker.d.ts.map