import type { ChangeEvent, KeyboardEvent, ReactNode } from 'react';
import type { BaseProps } from '../../../types';
import type { FormControlProps } from '../../FormControl';
import type { Selected } from '../ComboBox.types';
export interface MultiSelectInputProps extends BaseProps {
    /** List of items to be represented as pills. */
    selected?: Selected[];
    /** Input value */
    value?: string;
    /** Callback fired when the list value is selected irrespective of the input value changes. */
    onRemove?: (id: string, index: number) => void;
    /** Callback invoked when user accepts custom value by pressing enter. */
    onNew?: (text: string) => void;
    /** Callback fired when internal input value changes. */
    onChange?: (e: ChangeEvent<HTMLInputElement>) => void;
    /** Callback fired on every key stroke on input field. */
    onKeyDown?: (e: KeyboardEvent<HTMLInputElement>) => void;
    /** Callback fired when AI suggestion is accepted/rejected */
    onResolveSuggestion?: FormControlProps['onResolveSuggestion'];
    /** Makes the input non editable and non clickable. The browser defaults to false. */
    readOnly?: FormControlProps['readOnly'];
    /** Disable the control. The browser defaults to false. */
    disabled?: FormControlProps['disabled'];
    /** Set visual state based on a validation state. */
    status?: FormControlProps['status'];
    /** Placeholder visible on empty input. */
    placeholder?: string;
    /** Additional actions related to the input. */
    actions?: ReactNode;
    /** Automatically focuses the input on render. */
    autoFocus?: boolean;
    /** Pause evaluation of selected item descendants */
    pauseDescendantEvaluation?: boolean;
    /** Callback on selected item pseudo focus */
    onSelectedFocus?: () => void;
    /** Callback on selected item pseudo blur */
    onSelectedBlur?: () => void;
    /** ID of pseudo-focus container controlled by input (ex: list, menu) */
    'aria-controls'?: string;
}
//# sourceMappingURL=MultiSelectInput.types.d.ts.map