import type { NoChildrenProp, OmitStrict, WithAttributes } from '../../types';
import type { FormControlProps } from '../FormControl';
export type ObfuscationMode = 'none' | 'partial' | 'full';
export interface FormattingOptions {
    obfuscation?: ObfuscationMode;
}
export type CreditCardDisplayProps = WithAttributes<'span', NoChildrenProp & {
    /** Number value. */
    value?: string;
    /** Options to define formatting. */
    formattingOptions?: {
        /**
         * Defines if the obfuscation (replacing digits with bullets) should be applied.
         * This is only visual obfuscation, the real one should be applied on the server side.
         * Characters that are going to be obfuscated may be random characters or even missing.
         * @default 'none'
         */
        obfuscation?: ObfuscationMode;
    };
}>;
export type CreditCardInputProps = OmitStrict<WithAttributes<'input', NoChildrenProp & {
    /** Set visual state based on a validation state. */
    status?: FormControlProps['status'];
    /** Pass a string or a fragment with an Icon and string. */
    label?: FormControlProps['label'];
    /**
     * Visually hides the label region.
     * @default false
     */
    labelHidden?: FormControlProps['labelHidden'];
    /** It is recommended to pass a simple string to offer guidance. Text will be styled based on status prop. */
    info?: FormControlProps['info'];
    /**
     * CurrencyInput input value.
     * Requires an onChange handler to update value.
     * @default ''
     */
    value?: string;
    /** Callback fired when input value changes. */
    onChange: (value?: string) => void;
    /** Callback fired when the component loses focus. */
    onFocus?: (value?: string) => void;
    /** Callback fired when the component loses focus. */
    onBlur?: (value?: string) => void;
    /** Pass a heading and content to show additional information on the field. */
    additionalInfo?: FormControlProps['additionalInfo'];
}>, 'type' | 'defaultValue'>;
//# sourceMappingURL=CreditCard.types.d.ts.map