import type { FunctionComponent } from 'react';
import type { FormControlProps } from '../../FormControl';
import type DateTimeProps from '../DateTime.types';
import type { DateRangeCallbackParameter, DateTimeProperties } from '../DateTime.types';
import type { ForwardProps } from '../../../types';
import type { MinuteInterval } from '../Picker/DatePicker.types';
import type { ClockFormat } from './utils';
export interface TimeRangeInputProps extends DateTimeProperties {
    /** Object of range boundaries. */
    value?: {
        start?: DateTimeProps['value'];
        end?: DateTimeProps['value'];
    };
    /** Callback fired when inputs value changes. */
    onChange: (value: DateRangeCallbackParameter) => void;
    /** Callback fired when the component gets focused. */
    onFocus?: (value: DateRangeCallbackParameter) => void;
    /** Callback fired when the component loses focus. */
    onBlur?: (value: DateRangeCallbackParameter) => void;
    /** Pass a string or a fragment with an Icon and string for first part of TimeRangeInput. */
    fromLabel?: FormControlProps['label'];
    /** Pass a string or a fragment with an Icon and string for second part of TimeRangeInput. */
    toLabel?: FormControlProps['label'];
    /** Pass an object with "heading" and "content" properties to show AdditionalInfo for second part of DataRangeInput. */
    toAdditionalInfo?: FormControlProps['additionalInfo'];
    /** Pass an object with "heading" and "content" properties to show AdditionalInfo for first part of DataRangeInput. */
    fromAdditionalInfo?: FormControlProps['additionalInfo'];
    /** Controls which input is displayed */
    mode: 'time' | 'datetime';
    /**
     * Display the time with seconds.
     * @default false
     */
    withSeconds?: boolean;
    /**
     * Defines interval for time picker options (in minutes).
     * @default 30
     */
    pickerInterval?: MinuteInterval;
    /** Defines clock format that overrides locale based format */
    clockFormat?: ClockFormat;
}
declare const _default: FunctionComponent<TimeRangeInputProps & ForwardProps> & {
    getTestIds: (testIdProp?: import("../../../types").TestIdProp["testId"]) => import("../../../types").TestIdsRecord<readonly ["from-time", "to-time", "from-date-time", "to-date-time", "label", "info", "additional-info", "suggestion-accept", "suggestion-reject"]>;
};
export default _default;
//# sourceMappingURL=TimeRangeInput.d.ts.map