import type { BaseProps, TestIdProp } from '../../../types';
import type { TimeInputProps } from '../Input/TimeInput';
export type MinuteInterval = 15 | 30 | 60;
export default interface DatePickerProps extends BaseProps, TestIdProp {
    /** Defines default date that will be selected when the Date Picker is opened. */
    selected?: Date;
    /** Callback fired when selected value changes. */
    onChange?: (date: Date) => void;
    /** Defines minimum available value that can be set by the user. */
    min?: string | number | Date;
    /** Defines maximum available value that can be set by the user. */
    max?: string | number | Date;
    /**
     * Display the time with seconds.
     * @default false
     */
    withSeconds?: boolean;
    /**
     * Displays additional column with week number.
     * @default false
     */
    showWeekNumber?: boolean;
    /**
     * Time input picker interval in minutes.
     * @default 30
     */
    pickerInterval?: TimeInputProps['pickerInterval'];
    /**
     * Clock format override for time input.
     * @default undefined
     */
    clockFormat?: TimeInputProps['clockFormat'];
    /**
     * The mode of the calendar that will be rendered, ie. whether single date or week are selectable.
     * @default 'date'
     */
    mode?: 'date' | 'datetime' | 'week';
}
//# sourceMappingURL=DatePicker.types.d.ts.map