import type { ReactNode, Ref } from 'react';
import type { ButtonProps } from '../Button';
import type { BaseProps, ForwardRefForwardPropsComponent, TestIdProp } from '../../types';
export interface LinkProps extends BaseProps, TestIdProp {
    /** Text or content for the Link. */
    children: ReactNode;
    /** URL or DOM id to navigate to. */
    href: string;
    /**
     * Controls the styling of the Link.
     * @default 'link'
     */
    variant?: ButtonProps['variant'];
    /**
     * Set the Icon prop to `true` if you're using just an Icon in your Link. Make sure to pass an Icon as children if `true`.
     * @default false
     */
    icon?: ButtonProps['icon'];
    /**
     * Determines if the Link should render a popover when focused or hovered over.
     * @default false
     */
    previewable?: boolean;
    /** Callback function that is run when the preview popover is interacted with. */
    onPreview?: (e: {
        href: string;
    }) => void;
    /** Specifies where to open the link href. */
    target?: string;
    /** Ref for the wrapping element. */
    ref?: Ref<HTMLAnchorElement>;
}
export declare const StyledLinkPopover: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {
    preview: boolean;
}, never>;
export declare const StyledLinkPopoverBtn: import("styled-components").StyledComponent<ForwardRefForwardPropsComponent<import("../Button/BareButton").BareButtonProps>, import("styled-components").DefaultTheme, {}, never>;
export declare const StyledLinkPreviewPopoverBtn: import("styled-components").StyledComponent<ForwardRefForwardPropsComponent<import("../Button/BareButton").BareButtonProps>, import("styled-components").DefaultTheme, {}, never>;
export declare const StyledLink: import("styled-components").StyledComponent<ForwardRefForwardPropsComponent<ButtonProps>, import("styled-components").DefaultTheme, {}, never>;
declare const _default: ForwardRefForwardPropsComponent<LinkProps> & {
    getTestIds: (testIdProp?: TestIdProp["testId"]) => import("../../types").TestIdsRecord<readonly ["preview-popover", "preview", "new-tab"]>;
};
export default _default;
//# sourceMappingURL=Link.d.ts.map