import type { WithAttributes } from '../../types';
import type { LatLng, Pin } from './Location.types';
export type LocationViewProps = WithAttributes<'div', {
    /**
     * Array of location objects.
     * @default []
     */
    pins?: Pin[];
    /**
     * Set to true to always center the map when the selected location changes. Toggling this from false to true will re-center map on the last pinned location.
     * @default false
     */
    centerMapOnChange?: boolean;
    /**
     * Height of the map container.
     * @default '25rem'
     */
    height?: string;
    /**
     * How much the map should zoom.
     * @default 13
     */
    zoomLevel?: number;
    /** Callback fired when user clicks on a location on the map. This function will be passed the coordinates of the location that was clicked. */
    onClick?: (locationData: LatLng & {
        name?: string;
        address?: string;
    }) => void;
    /**
     * Renders loading indicator when true. Informs the user location resolution is in progress.
     */
    loading?: boolean;
    /**
     * Disables dragging and clicking when true.
     * @default false
     */
    disabled?: boolean;
    /**
     * Indicates if route between pins should be rendered.
     * @default false
     */
    drawRoute?: boolean;
    /** Callback fired when an error occurs. This function gets called with one argument of type Error. */
    onError?: (error: Error) => void;
}>;
declare const LocationView: import("react").ForwardRefExoticComponent<Omit<LocationViewProps, "ref"> & import("react").RefAttributes<HTMLDivElement>>;
export default LocationView;
//# sourceMappingURL=LocationView.d.ts.map