/// <reference types="google.maps" preserve="true" />
import type { Bias, LatLng, ProviderOpts, Location } from './Location.types';
export declare function loadMapsAPI(name?: string, opts?: ProviderOpts): Promise<void>;
/**
 * Identifies coordinates in degree format
 * eg. 45.78°N 9.11°E
 */
export declare function isValueDegreeFormatCoordinate(value: string): boolean;
/**
 * Identifies coordinates in degree, minute format
 * eg. 45°45.4’N 9°23’E
 */
export declare function isValueDMCoordinate(value: string): boolean;
/**
 * Identifies coordinates in degree, minute, second format
 * eg. 45°45’32.4″N 9°23’39.9″E
 */
export declare function isValueDMSCoordinate(value: string): boolean;
/**
 * Identifies coordinates in decimal format
 * eg. 14.678, -38.765
 */
export declare function isValueACoordinate(value: string): boolean;
/**
 * Parses DMS (degree, minute, second) format string into decimal format coordinates.
 */
export declare function parseDMS(input: string): number[];
export declare function getNavigatorPosition(): Promise<LatLng>;
export declare function toGoogleLatLng(coords: LatLng): google.maps.LatLng;
/** Returns an array of place prediction objects ('place' can be an establishment, geographic location, or prominent point of interest)
 * and  session token (valid for multiple queries, followed by one place selection).
 */
export declare function getPlacePredictions(location: string, bias?: Bias): Promise<{
    placePredictions: google.maps.places.AutocompletePrediction[];
    token: google.maps.places.AutocompleteSessionToken;
}>;
export declare function getPlace(location: string, mapElement?: HTMLDivElement): Promise<LatLng>;
export declare function getPlaceById(placeId: string, sessionToken?: google.maps.places.AutocompleteSessionToken, mapElement?: HTMLDivElement): Promise<Location>;
/** Returns coordinations for given input: either coords, address or current position. */
export declare function getCoords(coords: string | 'current' | LatLng, mapElement?: HTMLDivElement): Promise<LatLng>;
export declare function getAddress(coords: LatLng): Promise<{
    name: string;
    address?: string;
    latitude: number;
    longitude: number;
}>;
export declare const isLatLngObject: (obj: unknown) => obj is google.maps.LatLng;
export declare const getGoogleMapsDirHref: (destination: string, waypoints: string[], travelMode?: string) => string;
//# sourceMappingURL=utils.d.ts.map