import type { ChangeEventHandler } from 'react';
import type { FormControlProps } from '../FormControl';
import type { NoChildrenProp, WithAttributes, TestIdProp } from '../../types';
import type { elements } from '../FormField/FormField.test-ids';
export type RadioCheckProps = WithAttributes<'input', NoChildrenProp & TestIdProp<typeof elements> & {
    /** Pass a string or a fragment with an Icon and string. */
    label?: FormControlProps['label'];
    /** Set visual state based on a validation state. */
    status?: FormControlProps['status'];
    /** Sets the type of input. */
    type: 'radio' | 'checkbox';
    /**
     * Sets control to an [indeterminate state](https://css-tricks.com/almanac/selectors/i/indeterminate/#indeterminate-checkboxes).
     * @default false
     */
    indeterminate?: boolean;
    /** Sets checked prop via onChange when using as controlled component. */
    checked?: boolean;
    /** Initialize checked prop when using as uncontrolled component. */
    defaultChecked?: boolean;
    /**
     * Controls the styling of the RadioCheck.
     * @default 'simple'
     */
    variant?: 'simple' | 'card';
    /** Pass a heading and content to show additional information on the field. */
    additionalInfo?: FormControlProps['additionalInfo'];
    /** info like error, success, warning messages */
    info?: FormControlProps['info'];
    /** Callback invoked when this particular radio button is selected. */
    onChange?: ChangeEventHandler<HTMLInputElement>;
    /** Pass a string used as input's aria-describedby. */
    ariaDescribedby?: string;
}>;
export declare const StyledPseudoRadioCheck: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, Pick<RadioCheckProps, "readOnly" | "status">, never>;
export declare const StyledRadioCheckInput: import("styled-components").StyledComponent<"input", import("styled-components").DefaultTheme, {}, never>;
export declare const StyledRadioCheck: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, Pick<RadioCheckProps, "disabled" | "readOnly">, never>;
export declare const StyledRadioCheckCard: import("styled-components").StyledComponent<"label", import("styled-components").DefaultTheme, Pick<RadioCheckProps, "disabled" | "readOnly" | "status">, never>;
declare const _default: import("react").ForwardRefExoticComponent<Omit<RadioCheckProps, "ref"> & import("react").RefAttributes<HTMLInputElement>> & {
    getTestIds: (testIdProp?: TestIdProp["testId"]) => import("../../types").TestIdsRecord<readonly ["control", "label", "info", "additional-info", "suggestion-accept", "suggestion-reject"]>;
};
export default _default;
//# sourceMappingURL=RadioCheck.d.ts.map