import type { ReactNode, Ref, ElementType } from 'react';
import type { GridContainerProps } from '../Grid';
import type { ForwardRefForwardPropsComponent, NoChildrenProp, TestIdProp } from '../../types';
export interface SummaryItemProps extends NoChildrenProp, TestIdProp {
    /** Region for the primary information. */
    primary: NonNullable<ReactNode>;
    /** Region for displaying supporting metadata. */
    secondary?: ReactNode;
    /**
     * Determines layout structure.
     * @default 'stacked'
     */
    layout?: 'stacked' | 'inline';
    /** Region for an Avatar, Icon, or other supporting visual. */
    visual?: ReactNode;
    /** Region for adding Actions, Buttons, or Links. */
    actions?: ReactNode;
    /** Override the default Grid container props on SummaryItem. */
    container?: GridContainerProps;
    /**
     * Determines how the text within primary and secondary fields should handle overflow.
     * @default 'wrap'
     */
    overflowStrategy?: 'wrap' | 'ellipsis';
    /** HTML tag to render the SummaryItem's element with. */
    as?: ElementType;
    /** Ref for the SummaryItem. */
    ref?: Ref<HTMLElement>;
}
export declare const StyledVisual: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
export declare const StyledPrimary: import("styled-components").StyledComponent<ForwardRefForwardPropsComponent<import("../Grid").GridProps>, import("styled-components").DefaultTheme, {
    isString?: boolean;
    overflowStrategy?: SummaryItemProps["overflowStrategy"];
}, never>;
export declare const StyledSecondary: import("styled-components").StyledComponent<ForwardRefForwardPropsComponent<import("../Grid").GridProps>, import("styled-components").DefaultTheme, {
    overflowStrategy?: SummaryItemProps["overflowStrategy"];
}, never>;
export declare const StyledSummaryItemActions: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
export declare const StyledSummaryItem: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
declare const _default: ForwardRefForwardPropsComponent<SummaryItemProps> & {
    getTestIds: (testIdProp?: TestIdProp["testId"]) => import("../../types").TestIdsRecord<readonly ["primary", "secondary", "visual", "actions"]>;
};
export default _default;
//# sourceMappingURL=SummaryItem.d.ts.map