interface UseElementFocusOptions {
    /** When the focus should be triggered */
    shouldFocus?: boolean;
    /** Delay in milliseconds to wait before focusing the element. */
    delay?: number;
    /** Focus on some special key press */
    triggerKey?: string;
}
type ElementOrRef = HTMLElement | null | React.RefObject<HTMLElement | null>;
/**
 * Usage: Focuses on the element based on the given condition
 * @example useElementFocus(elementRef, {delay: 300, shouldFocus, triggerKey: 'space'})
 * @param elementRef ref of the element to focus
 * @param shouldFocus boolean value to specify if the element should be focused or not
 * @param delay focus on the given ref after some delay in milliseconds.
 * @param triggerKey click on the ref element if this key is pressed
 */
declare const useElementFocus: (elementOrRef: ElementOrRef, { shouldFocus, delay, triggerKey }?: UseElementFocusOptions) => void;
export default useElementFocus;
//# sourceMappingURL=useElementFocus.d.ts.map