import { useCallback } from 'react';
import useEvent from './useEvent';
/**
 * Hook to define function triggered on Escape button. It attaches the listener to the element
 * identified by target prop, defaults to document. Used primarily for convenience when dismissing
 * popovers.
 * @example useEscape((event) => { do something });
 * @param cb The function that should be executed on keydown keyevent.
 * @param target To which esc event to be attached - Defaults to document
 * @param dependencies List of dependencies
 */
const useEscape = (cb, target = document, dependencies = []) => {
    const onKeyDown = useCallback((e) => {
        if (e.key === 'Escape')
            cb(e);
    }, [cb, ...dependencies]);
    useEvent('keydown', onKeyDown, { target });
};
export default useEscape;
//# sourceMappingURL=useEscape.js.map