/**
 * Gets element that currently has focus with support for open shadow roots.
 * @param root Optional container to search for the active element. Defaults to `document`.
 * @returns The Element within the DOM that currently has focus.
 */
const getActiveElement = (root = document) => {
    let activeEl = root.activeElement;
    if (!activeEl)
        return null;
    if (activeEl.tagName.toLowerCase() === 'iframe' &&
        activeEl.contentDocument)
        activeEl = getActiveElement(activeEl.contentDocument) ?? activeEl;
    if (activeEl.shadowRoot)
        activeEl = getActiveElement(activeEl.shadowRoot) ?? activeEl;
    return activeEl;
};
export default getActiveElement;
//# sourceMappingURL=getActiveElement.js.map